# Uprotocol Rust bindings for Python

![CI Status](https://github.com/sachinkum0009/up-py/actions/workflows/CI.yml/badge.svg?branch=main) [![PyPI version](https://img.shields.io/pypi/v/up-py-rs.svg)](https://pypi.org/project/up-py-rs/)

This repo provides UProtocol binding to use in Python. It is built using Maturin and Pyo3

## Commands

```bash
maturin develop
```

